@@ -5,12 +5,15 @@ import sys
 from termcolor import colored
 import json
 # from .helper import set_logger
+from aicmder.common import set_logger, LOG_VERBOSE
 
 # 8s for timeout
 REQUEST_TIMEOUT = 8000  
 REQUEST_RETRIES = 3
 SERVER_ENDPOINT = "tcp://localhost:5555"
-logging.basicConfig(format="%(levelname)s: %(message)s", level=logging.INFO)
+
+verbose = LOG_VERBOSE
+logging = set_logger(colored('SERVER_QUEUE', 'magenta'), verbose)
 
 
 class Client:
@@ -112,7 +115,7 @@ class HTTPProxy(Process):
         def predict(data: dict, request: Request):
             # data = request.form if request.form else request.json
             try:
-                print(request, data)
+                logging.debug(request, data)
                 json_str = json.dumps(data)
                 # logger.info('new request from %s' % request.client.host)
                 result = self.concurrent.send_request(json_str.encode())
